@@ -53,7 +53,7 @@ from ingenialink.exceptions import (
 )
 from ingenialink.register import Register
 from ingenialink.utils._utils import convert_bytes_to_dtype, convert_dtype_to_bytes
-from ingenialink.virtual.dictionary import VirtualDictionary
+from ingenialink.virtual.dictionary import VirtualDictionaryV2, VirtualDictionaryV3
 
 logger = ingenialogger.get_logger(__name__)
 
@@ -105,8 +105,10 @@ class DictionaryFactory:
                 return EthercatDictionaryV3(dictionary_path)
             if interface == Interface.EoE:
                 return EoEDictionaryV3(dictionary_path)
-            if interface in [Interface.ETH, Interface.VIRTUAL]:
+            if interface == Interface.ETH:
                 return EthernetDictionaryV3(dictionary_path)
+            if interface == Interface.VIRTUAL:
+                return VirtualDictionaryV3(dictionary_path)
         if major_version == 2:
             if interface == Interface.CAN:
                 return CanopenDictionaryV2(dictionary_path)
@@ -115,7 +117,7 @@ class DictionaryFactory:
             if interface in [Interface.ETH, Interface.EoE]:
                 return EthernetDictionaryV2(dictionary_path)
             if interface == Interface.VIRTUAL:
-                return VirtualDictionary(dictionary_path)
+                return VirtualDictionaryV2(dictionary_path)
         raise NotImplementedError(
             f"Dictionary version {major_version} is not supported for interface {interface.name}"
         )
@@ -252,14 +254,12 @@ class Servo:
     SERIAL_NUMBER_REGISTERS = (
         "DRV_ID_SERIAL_NUMBER_COCO",
         "DRV_ID_SERIAL_NUMBER",
-        "FSOE_SERIAL_NUMBER",
     )
     SOFTWARE_VERSION_REGISTERS = (
         "DRV_APP_COCO_VERSION",
         "DRV_ID_SOFTWARE_VERSION",
-        "FSOE_SOFTWARE_VERSION",
     )
-    PRODUCT_ID_REGISTERS = ("DRV_ID_PRODUCT_CODE_COCO", "DRV_ID_PRODUCT_CODE", "FSOE_PRODUCT_CODE")
+    PRODUCT_ID_REGISTERS = ("DRV_ID_PRODUCT_CODE_COCO", "DRV_ID_PRODUCT_CODE")
     REVISION_NUMBER_REGISTERS = ("DRV_ID_REVISION_NUMBER_COCO", "DRV_ID_REVISION_NUMBER")
     MONITORING_DIST_ENABLE = "MON_DIST_ENABLE"
     MONITORING_REMOVE_DATA = "MON_REMOVE_DATA"
@@ -1166,19 +1166,18 @@ class Servo:
         for callback in self.__observers_servo_state:
             callback(state, subnode)
 
-    def __read_coco_moco_saco_register(
-        self, register_coco: str, register_moco: str, register_saco: Optional[str]
+    def __read_coco_moco_register(
+        self,
+        register_coco: str,
+        register_moco: str,
     ) -> str:
         """Read a register from COCO or MOCO.
 
         If it does not exist, reads the MOCO register.
-        If it does not exist, reads the SACO register.
 
         Args:
             register_coco: COCO Register ID to be read.
             register_moco: MOCO Register ID to be read.
-            register_saco: SACO Register ID to be read.
-                None if there is no equivalent SACO register.
 
         Raises:
             ILError: if there is an error reading the register.
@@ -1193,13 +1192,7 @@ class Servo:
         try:
             return str(self.read(register_moco, subnode=1))
         except ILError:
-            if register_saco is None:
-                raise ILError(f"Error reading register {register_moco} from MOCO.")
-            logger.warning(f"Error reading register {register_moco} from MOCO. Trying SACO")
-        try:
-            return str(self.read(register_saco, subnode=4))
-        except ILError:
-            raise ILError(f"Error reading register {register_saco} from SACO.")
+            raise ILError(f"Error reading register {register_moco} from MOCO.")
 
     def __monitoring_map_register(self) -> str:
         """Get the first available Monitoring Mapped Register slot.
@@ -1793,32 +1786,29 @@ class Servo:
     def info(self) -> dict[str, Union[None, str, int]]:
         """Servo information."""
         try:
-            serial_number = self.__read_coco_moco_saco_register(
+            serial_number = self.__read_coco_moco_register(
                 self.SERIAL_NUMBER_REGISTERS[0],
                 self.SERIAL_NUMBER_REGISTERS[1],
-                self.SERIAL_NUMBER_REGISTERS[2],
             )
         except ILError:
             serial_number = None
         try:
-            sw_version = self.__read_coco_moco_saco_register(
+            sw_version = self.__read_coco_moco_register(
                 self.SOFTWARE_VERSION_REGISTERS[0],
                 self.SOFTWARE_VERSION_REGISTERS[1],
-                self.SOFTWARE_VERSION_REGISTERS[2],
             )
         except ILError:
             sw_version = None
         try:
-            product_code = self.__read_coco_moco_saco_register(
+            product_code = self.__read_coco_moco_register(
                 self.PRODUCT_ID_REGISTERS[0],
                 self.PRODUCT_ID_REGISTERS[1],
-                self.PRODUCT_ID_REGISTERS[2],
             )
         except ILError:
             product_code = None
         try:
-            revision_number = self.__read_coco_moco_saco_register(
-                self.REVISION_NUMBER_REGISTERS[0], self.REVISION_NUMBER_REGISTERS[1], None
+            revision_number = self.__read_coco_moco_register(
+                self.REVISION_NUMBER_REGISTERS[0], self.REVISION_NUMBER_REGISTERS[1]
             )
         except ILError:
             revision_number = None
