@@ -1,7 +1,7 @@
 import pytest
 
 import tests.resources
-from ingenialink.virtual.dictionary import VirtualDictionary
+from ingenialink.virtual.dictionary import VirtualDictionaryV2
 
 
 @pytest.mark.no_connection
@@ -11,7 +11,7 @@ def test_read_xdf_register_ethernet():
     reg_id = "DRV_DIAG_ERROR_LAST_COM"
     subnode = 0
 
-    ethernet_dict = VirtualDictionary(dictionary_path)
+    ethernet_dict = VirtualDictionaryV2(dictionary_path)
 
     assert ethernet_dict.registers(subnode)[reg_id].address == address
 
@@ -24,6 +24,19 @@ def test_read_xdf_register_ethernet():
 def test_read_xdf_register_canopen(reg_id, subnode, address):
     dictionary_path = tests.resources.canopen.TEST_DICT_CAN
 
-    ethernet_dict = VirtualDictionary(dictionary_path)
+    ethernet_dict = VirtualDictionaryV2(dictionary_path)
 
     assert ethernet_dict.registers(subnode)[reg_id].address == address
+
+
+@pytest.mark.no_connection
+def test_no_cia_registers_in_dictionary():
+    dictionary_path = tests.resources.canopen.TEST_DICT_CAN
+
+    virtual_dict = VirtualDictionaryV2(dictionary_path)
+
+    assert "CIA402" not in virtual_dict.categories.category_ids
+
+    for subnode in virtual_dict.subnodes:
+        for register in virtual_dict.registers(subnode):
+            assert not register.startswith("CIA")
